<?xml version="1.0"?>

<!--
pdf.xsl

Copyright (c) 2000 Sean Kelly
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the
   distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

$Id$
-->

<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:fo="http://www.w3.org/1999/XSL/Format"
>

  <xsl:output method="xml" omit-xml-declaration="no" indent="yes"/>
  <xsl:output doctype-public=""/>
  <xsl:strip-space elements="*"/>

  <!-- Got what we assume is a resume -->
  <xsl:template match="/">
    <fo:root>
      <fo:layout-master-set>
	<fo:simple-page-master page-master-name="first" page-height="11in"
			       page-width="8.5in" margin-top="0.1in"
			       margin-bottom="0.1in" margin-left="0.1in"
			       margin-right="0.1in"
			       overflow="paginate">
	  <fo:region-start extent="2.2in"/>
	  <fo:region-before extent="0.7in"/>
	  <fo:region-body margin-left="2.2in" margin-right="0.7in"
			  margin-top="0.7in" margin-bottom="0.7in"
			  column-count="1"/>
	  <fo:region-after extent="0.7in"/>
	  <fo:region-end extent="0.7in"/>
	</fo:simple-page-master>
	<fo:simple-page-master page-master-name="rest" page-height="11in"
			       page-width="8.5in" margin-top="0.1in"
			       margin-bottom="0.1in" margin-left="0.1in"
			       margin-right="0.1in"
			       overflow="paginate">
	  <fo:region-start extent="2.2in"/>
	  <fo:region-before extent="0.7in"/>
	  <fo:region-body margin-left="2.2in" margin-right="0.7in"
			  margin-top="0.7in" margin-bottom="0.7in"
			  column-count="1"/>
	  <fo:region-after extent="0.7in"/>
	  <fo:region-end extent="0.7in"/>
	</fo:simple-page-master>
      </fo:layout-master-set>

      <fo:page-sequence>
	<fo:sequence-specification>
	  <fo:sequence-specifier-repeating page-master-first="first"
					   page-master-repeating="rest"/>
	  <fo:title>
	    <xsl:apply-templates select="resume/header/name"/>'s Resume
	  </fo:title>
	</fo:sequence-specification>

	<!-- Running headers/footers -->
	<fo:static-content flow-name="xsl-after">
	  <fo:block text-align="start" font-size="8pt"
		    font-family="serif" line-height="9pt"
		    text-indent="0.7in">
	    <xsl:apply-templates select="resume/header/name"/>'s
	    Resume - page <fo:page-number/>
	  </fo:block>
	</fo:static-content>

	<fo:flow flow-name="xsl-body">
	  <xsl:apply-templates select="resume"/>
	</fo:flow>
      </fo:page-sequence>
    </fo:root>
  </xsl:template>

  <!-- Format a heading -->
  <xsl:template name="heading">
    <xsl:param name="text">Heading</xsl:param>
    <fo:block font-size="10pt" font-family="serif" font-weight="bold"
	      line-height="12pt" text-align="start"
	      text-indent="-1.5in" border-top-style="dotted"
	      border-top-color="black" border-top-width="3pt"
	      space-after.optimum="3pt" space-before.optimum="3pt">
      <xsl:value-of select="$text"/>
    </fo:block>
  </xsl:template>

  <!-- Suppress stuff not needed for print presentation -->
  <xsl:template match="docpath"/>
  <xsl:template match="keywords"/>

  <!-- Header information -->
  <xsl:template match="header">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      text-align="start" space-after.optimum="3pt" padding="3pt">
      <fo:block font-weight="bold">
	<xsl:apply-templates select="name"/>
      </fo:block>
      <xsl:apply-templates select="address"/>
      <xsl:apply-templates select="contact"/>
    </fo:block>
  </xsl:template>

  <xsl:template match="name">
    <xsl:value-of select="firstname"/>
    <xsl:text> </xsl:text>
    <xsl:value-of select="surname"/>
  </xsl:template>
  
  <xsl:template match="address">
    <fo:block>
      <fo:block><xsl:value-of select="street"/></fo:block>
      <fo:block>
	<xsl:value-of select="city"/>,
        <xsl:value-of select="state"/><xsl:text> </xsl:text><xsl:value-of select="zip"/>
      </fo:block>
    </fo:block>
  </xsl:template>

  <xsl:template match="contact">
    <fo:block>
      <fo:block>
	<fo:inline font-style="italic">Phone:</fo:inline>
	<xsl:text> </xsl:text>
	<xsl:value-of select="phone"/>
      </fo:block>
      <fo:block>
	<fo:inline font-style="italic">Email:</fo:inline>
	<xsl:text> </xsl:text>
	<xsl:value-of select="email"/>
      </fo:block>
      <fo:block>
	<fo:inline font-style="italic">URL:</fo:inline>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="url"/>
      </fo:block>
    </fo:block>
  </xsl:template>

  <!-- Got the guy's objective -->
  <xsl:template match="objective">
    <xsl:call-template name="heading">
      <xsl:with-param name="text">Professional
      Objective</xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates/>
  </xsl:template>

  <!-- Job history -->
  <xsl:template match="history">
    <xsl:call-template name="heading">
      <xsl:with-param name="text">Employment History</xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="job"/>
  </xsl:template>

  <!-- A job -->
  <xsl:template match="job">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      space-after.optimum="3pt" text-align="start">
      <fo:inline font-weight="bold"><xsl:value-of select="jobtitle"/></fo:inline>
      -
      <fo:inline font-style="italic"><xsl:value-of select="employer"/></fo:inline>
      -
      <fo:inline font-style="italic"><xsl:apply-templates select="period"/></fo:inline>
      <fo:block space-before.optimum="6pt">
        <xsl:apply-templates select="description"/>
      </fo:block>
    </fo:block>
  </xsl:template>

  <!-- Academics -->
  <xsl:template match="academics">
    <fo:block break-before="page"/>
    <xsl:call-template name="heading">
      <xsl:with-param name="text">Academics</xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="degrees"/>
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      space-after.optimum="3pt" text-align="start" font-style="italic">
      <xsl:apply-templates select="note"/>
    </fo:block>
  </xsl:template>

  <!-- A degree -->
  <xsl:template match="degree">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt" text-align="start">
      <fo:inline font-weight="bold"><xsl:value-of select="level"/> in
        <xsl:value-of select="subject"/></fo:inline>,
      <xsl:apply-templates select="date"/>,
      <xsl:apply-templates select="annotation"/>
    </fo:block>
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      space-after.optimum="3pt" text-align="start">
      <xsl:value-of select="institution"/>
    </fo:block>
  </xsl:template>

  <!-- Each skill area -->
  <xsl:template match="skillarea">
    <xsl:call-template name="heading">
      <xsl:with-param name="text"><xsl:value-of select="title"/></xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="skillset"/>
  </xsl:template>

  <!-- A set of skills -->
  <xsl:template match="skillset">
    <xsl:apply-templates select="title"/>
    <xsl:apply-templates select="skills"/>
  </xsl:template>

  <xsl:template match="skills">
    <fo:list-block space-after.optimum="3pt">
      <xsl:apply-templates select="skill"/>
    </fo:list-block>
  </xsl:template>

  <!-- A title of a skill set -->
  <xsl:template match="skillset/title">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      space-after.optimum="3pt" text-align="start" font-style="italic">
      <xsl:value-of select="."/>
    </fo:block>
  </xsl:template>

  <!-- An individual skill -->
  <xsl:template match="skill">
    <fo:list-item>
      <fo:list-item-label>
	<fo:block font-size="10pt" font-family="serif" line-height="12pt"
		  text-align="start">
	  &#x2022;
	</fo:block>
      </fo:list-item-label>
      <fo:list-item-body>
        <fo:block font-size="10pt" font-family="serif" line-height="12pt"
		  text-align="start">
          <xsl:value-of select="."/>
	</fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <!-- Publications -->
  <xsl:template match="pubs">
    <xsl:call-template name="heading">
      <xsl:with-param name="text">Publications</xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="pub"/>
  </xsl:template>

  <!-- Miscellaneous stuff -->
  <xsl:template match="misc">
    <xsl:call-template name="heading">
      <xsl:with-param name="text">Miscellany</xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="para"/>
  </xsl:template>

  <!-- Legalese -->
  <xsl:template match="copyright">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      text-align="start" space-after.optimum="3pt"
	      padding="3pt" space-before.optimum="16pt">
      Copyright (c) <xsl:value-of select="year"/>
      by <xsl:apply-templates select="/resume/header/name"/>.
	<xsl:apply-templates select="legalnotice"/>
    </fo:block>
  </xsl:template>

  <!-- Format a period of dates -->
  <xsl:template match="period">
    <xsl:apply-templates select="from"/>-<xsl:apply-templates select="to"/>
  </xsl:template>

  <!-- Format a date -->
  <xsl:template match="date">
    <xsl:value-of select="month"/>
    <xsl:text> </xsl:text>
    <xsl:value-of select="year"/>
  </xsl:template>

  <!-- In a date with just "present", format it as the word "present". -->
  <xsl:template match="present">Present</xsl:template>

  <!-- Format a simple paragraph -->
  <xsl:template match="para">
    <fo:block font-size="10pt" font-family="serif" line-height="12pt"
	      space-after.optimum="6pt" text-align="start">
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>

  <!-- Format emphasis -->
  <xsl:template match="emphasis">
    <fo:inline font-weight="bold">
      <xsl:value-of select="."/>
    </fo:inline>
  </xsl:template>

  <!-- Format a citation -->
  <xsl:template match="citation">
    <fo:inline font-style="italic">
      <xsl:value-of select="."/>
    </fo:inline>
  </xsl:template>

  <!-- Format a URL -->
  <xsl:template match="url">
    <fo:inline font-family="monospace">
      <xsl:value-of select="."/>
    </fo:inline>
  </xsl:template>

</xsl:stylesheet>
